#line 1 "giscanner/scannerlexer.c"

#line 3 "giscanner/scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 173
#define YY_END_OF_BUFFER 174
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[1157] =
    {   0,
      174,  172,  173,    3,  172,  173,    1,  173,   45,  172,
      173,  172,  173,   20,  172,  173,   40,  172,  173,   42,
      172,  173,  172,  173,   29,  172,  173,   30,  172,  173,
       38,  172,  173,   36,  172,  173,   69,  172,  173,   37,
      172,  173,   35,  172,  173,   39,  172,  173,  165,  172,
      173,  165,  172,  173,   32,  172,  173,   31,  172,  173,
       47,  172,  173,   46,  172,  173,   48,  172,  173,   34,
      172,  173,  110,  162,  172,  173,  110,  162,  172,  173,
      110,  162,  172,  173,  110,  162,  172,  173,  110,  162,
      172,  173,   25,  172,  173,  172,  173,   27,  172,  173,

       41,  172,  173,  110,  162,  172,  173,  110,  162,  172,
      173,  110,  162,  172,  173,  110,  162,  172,  173,  110,
      162,  172,  173,  110,  162,  172,  173,  110,  162,  172,
      173,  110,  162,  172,  173,  110,  162,  172,  173,  110,
      162,  172,  173,  110,  162,  172,  173,  110,  162,  172,
      173,  110,  162,  172,  173,  110,  162,  172,  173,  110,
      162,  172,  173,  110,  162,  172,  173,   21,  172,  173,
       43,  172,  173,   23,  172,  173,   44,  172,  173,    3,
        1,   62,  170,   53,   24,   65,   55,  168,   51,   67,
       49,   68,   50,   70,  166,    4,    6,   52,  166,  164,

      165,  165,  165,  165,   28,   22,   26,   57,   63,   61,
       64,   58,  110,  162,  110,  162,  110,  162,  110,  162,
        2,   54,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  119,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  136,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,   56,   66,   33,  166,    6,  164,

      165,  164,  165,  167,  165,  165,  165,  163,   59,   60,
      110,  162,  110,  162,  171,  169,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  111,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  134,  162,  110,  162,
      110,  162,  110,  138,  162,  110,  162,  110,  162,  110,

      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  166,  164,  165,  164,  165,  164,  165,  167,  165,
      163,  163,  110,  162,  110,  162,  110,  162,  106,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  112,  162,

       97,  110,  162,  110,  162,  110,  114,  162,  110,  115,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      121,  162,  110,  122,  162,  110,  162,  110,  162,  110,
      162,  110,  135,  162,  110,  162,  110,  144,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  108,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  159,
      162,  110,  162,  110,  162,   18,   13,  164,  165,  163,
      163,  163,  107,  110,  162,  110,  162,  110,  162,   96,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,

      110,  162,   74,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  103,  110,  162,
      110,  113,  162,  110,  116,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  109,  110,  162,  110,  124,  162,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  148,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  157,  162,  110,  162,
      110,  162,  110,  161,  162,   15,  163,  110,  162,  110,

      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  120,  162,  110,  123,  162,  110,
      137,  162,  110,  162,  110,  162,  110,  147,  162,  110,
      149,  162,  110,  152,  162,  110,  153,  162,  110,  154,
      162,  110,  155,  162,  110,  162,  110,  162,  110,  162,
      110,  162,   14,   16,    5,  110,  162,  110,  162,  110,

      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,   75,  110,  162,  110,  162,
       99,  110,  162,   78,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  162,  110,  162,  110,  139,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  118,  162,
      110,  162,  110,  162,  110,  162,  110,  156,  162,  110,
      162,  110,  162,   12,  110,  162,  110,  162,  110,  162,
      110,  125,  162,  110,  126,  162,  110,  127,  162,   83,
      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,

      110,  162,  110,  162,  110,  162,  110,  162,  110,  162,
       81,  110,  162,  110,  143,  162,  110,  162,   87,  110,
      162,  110,  162,  110,  150,  162,  110,  162,   93,  110,
      162,  110,  162,  110,  162,  110,  117,  162,  110,  145,
      162,  110,  146,  162,  110,  162,  110,  158,  162,  110,
      160,  162,    8,   11,   19,   17,  110,  162,  110,  162,
      110,  128,  162,  110,  129,  162,  110,  130,  162,   86,
      110,  162,  110,  162,   84,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  132,  162,
      110,  162,  110,  162,   82,  110,  162,  110,  162,  110,

      162,  102,  110,  162,  110,  162,  110,  142,  162,  110,
      162,  110,  162,    7,    8,  110,  162,  110,  162,  110,
      131,  162,  110,  162,  110,  162,  110,  162,  110,  162,
      110,  162,  110,  133,  162,   80,  110,  162,  110,  141,
      162,   88,  110,  162,  110,  151,  162,   92,  110,  162,
      110,  162,   94,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,   77,  110,  162,  110,  162,
      110,  162,  110,  140,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,  110,  162,  110,  162,  110,
      162,   89,  110,  162,   95,  110,  162,   90,  110,  162,

      110,  162,  110,  162,  110,  162,   91,  110,  162,   76,
      110,  162,  101,   79,  110,  162,  110,  162,  110,  162,
      110,  162,   71,  110,  162,  110,  162,  110,  162,  110,
      162,  110,  162,  110,  162,   72,  104,  110,  162,  110,
      162,   85,  110,  162,  105,  110,  162,   73,    9,    9,
       12,   10,   10,   11,  100,   98
    } ;

static const flex_int16_t yy_accept[759] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   85,   89,   93,   96,   98,  101,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  160,  164,  168,  171,  174,  177,  180,  181,  182,
      183,  183,  184,  184,  184,  184,  184,  184,  184,  184,
      185,  186,  187,  188,  188,  189,  189,  190,  191,  192,
      193,  194,  195,  195,  196,  197,  198,  199,  200,  202,
      203,  203,  204,  205,  205,  206,  207,  208,  209,  210,

      211,  212,  213,  215,  217,  219,  219,  219,  221,  222,
      223,  225,  227,  229,  231,  233,  235,  237,  239,  241,
      243,  245,  247,  249,  252,  254,  256,  258,  260,  262,
      264,  266,  269,  271,  273,  275,  277,  279,  281,  283,
      285,  287,  289,  291,  293,  295,  296,  297,  297,  297,
      297,  297,  297,  297,  297,  298,  298,  299,  299,  299,
      300,  302,  304,  304,  305,  306,  307,  308,  309,  310,
      311,  313,  315,  315,  316,  316,  316,  317,  317,  319,
      321,  323,  325,  327,  329,  331,  333,  335,  337,  339,
      341,  343,  345,  347,  349,  351,  353,  355,  357,  360,

      362,  364,  366,  368,  370,  372,  374,  376,  378,  380,
      382,  384,  386,  389,  391,  393,  396,  398,  400,  402,
      404,  406,  408,  410,  412,  414,  416,  418,  420,  422,
      424,  426,  428,  430,  432,  432,  432,  432,  432,  432,
      432,  432,  432,  432,  432,  432,  433,  433,  435,  437,
      439,  440,  441,  442,  443,  445,  447,  449,  452,  454,
      456,  458,  460,  462,  464,  466,  468,  470,  472,  474,
      476,  478,  480,  482,  484,  486,  488,  490,  492,  494,
      496,  498,  501,  504,  506,  509,  512,  514,  516,  518,
      520,  523,  526,  528,  530,  532,  535,  537,  540,  542,

      544,  546,  548,  550,  552,  554,  556,  558,  560,  563,
      565,  567,  569,  572,  574,  576,  576,  577,  577,  577,
      577,  577,  577,  578,  578,  578,  578,  578,  578,  580,
      581,  582,  583,  586,  588,  590,  593,  595,  597,  599,
      601,  603,  606,  608,  610,  612,  614,  616,  618,  620,
      622,  624,  626,  628,  630,  632,  634,  636,  638,  641,
      644,  647,  649,  651,  653,  655,  658,  661,  663,  665,
      667,  669,  672,  674,  676,  678,  680,  682,  684,  686,
      689,  691,  693,  696,  696,  696,  696,  697,  697,  697,
      697,  697,  697,  697,  697,  698,  700,  702,  704,  706,

      708,  710,  712,  714,  714,  716,  718,  720,  722,  724,
      726,  728,  730,  732,  734,  736,  738,  740,  742,  744,
      746,  748,  750,  752,  754,  757,  760,  763,  765,  767,
      770,  773,  776,  779,  782,  785,  787,  789,  791,  793,
      793,  793,  794,  794,  795,  795,  795,  795,  795,  795,
      796,  798,  800,  802,  804,  806,  808,  810,  812,  814,
      816,  816,  819,  821,  824,  827,  829,  831,  833,  835,
      837,  840,  842,  844,  846,  848,  850,  852,  854,  856,
      858,  861,  863,  865,  867,  870,  872,  874,  874,  874,
      874,  874,  875,  875,  875,  875,  875,  875,  877,  879,

      881,  884,  887,  890,  893,  895,  897,  899,  901,  901,
      901,  903,  905,  907,  909,  911,  914,  917,  919,  922,
      924,  927,  929,  932,  934,  936,  939,  942,  945,  947,
      947,  950,  953,  954,  954,  954,  954,  954,  954,  955,
      955,  955,  956,  956,  957,  959,  961,  964,  967,  970,
      973,  975,  978,  980,  980,  980,  980,  982,  984,  986,
      988,  991,  993,  995,  998, 1000, 1002, 1005, 1007, 1010,
     1012, 1014, 1014, 1015, 1016, 1016, 1016, 1016, 1016, 1018,
     1020, 1023, 1025, 1027, 1027, 1027, 1027, 1029, 1031, 1033,
     1036, 1039, 1042, 1045, 1048, 1051, 1053, 1056, 1058, 1058,

     1058, 1058, 1058, 1058, 1060, 1062, 1064, 1066, 1066, 1066,
     1066, 1069, 1069, 1069, 1071, 1073, 1076, 1078, 1080, 1080,
     1080, 1080, 1080, 1080, 1082, 1084, 1086, 1088, 1088, 1088,
     1088, 1090, 1090, 1090, 1090, 1092, 1095, 1098, 1101, 1101,
     1101, 1101, 1101, 1101, 1103, 1105, 1107, 1110, 1110, 1110,
     1110, 1113, 1114, 1114, 1117, 1117, 1117, 1117, 1117, 1117,
     1119, 1121, 1123, 1124, 1124, 1124, 1124, 1124, 1124, 1124,
     1124, 1124, 1126, 1128, 1130, 1130, 1130, 1130, 1130, 1130,
     1130, 1130, 1130, 1132, 1134, 1136, 1136, 1137, 1137, 1137,
     1137, 1137, 1137, 1137, 1140, 1142, 1145, 1145, 1145, 1145,

     1145, 1145, 1145, 1145, 1148, 1148, 1148, 1148, 1148, 1148,
     1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1148, 1149,
     1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
     1150, 1150, 1150, 1152, 1152, 1152, 1152, 1152, 1152, 1152,
     1153, 1153, 1153, 1155, 1155, 1155, 1155, 1156, 1156, 1156,
     1156, 1156, 1156, 1156, 1156, 1156, 1157, 1157
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   25,   27,   28,   29,   30,   31,
       32,   33,   34,    1,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   42,   42,   44,   42,   45,   46,   42,
       42,   47,   48,   49,   50,   42,   42,   51,   42,   42,
       52,   53,   54,   55,   56,    1,   57,   58,   59,   60,

       61,   62,   63,   64,   65,   66,   67,   68,   69,   70,
       71,   72,   66,   73,   74,   75,   76,   77,   78,   79,
       80,   81,   82,   83,   84,   85,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[86] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    5,    1,    1,    1,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    1,    1,
        1,    5,    1,    1,    7,    7,    7,    7,    8,    9,
       10,   10,   10,   11,   10,   10,   10,   10,   10,   10,
       10,    1,    1,    1,    1,   10,   12,   12,   12,   12,
       13,   14,   15,   15,   15,   15,   15,   16,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   15,   15,   15,
       15,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[788] =
    {   0,
        0,    0, 1422, 1423,   84,    0, 1389,   80,   85,   59,
       83,   83, 1423, 1423, 1388,   80, 1423,   81,   79,   97,
      140,  202, 1386, 1423,   99, 1386,   77, 1423,    0, 1382,
     1360,  110, 1368, 1423, 1411, 1423, 1381,   98,   44,   51,
       68,   66,   72,   84, 1341,   86, 1340, 1349,  105,  108,
     1339, 1337, 1343, 1423,   91, 1423, 1423,  171,    0, 1423,
      142, 1423, 1403,  211, 1344,  117, 1342, 1338, 1329, 1423,
     1423, 1423, 1423,  124, 1423, 1398, 1423, 1423, 1423, 1423,
     1423, 1423, 1382,  153,  238,    0, 1423,  205,  203,    0,
      266,  230,  134,    0, 1423, 1423, 1423, 1367, 1423, 1423,

     1423, 1366,    0, 1353, 1355,  152,  133, 1345, 1423, 1423,
     1323, 1325,  118, 1328,  250, 1322, 1315, 1318, 1327, 1313,
     1329, 1315, 1322, 1307, 1308, 1305, 1305, 1311, 1307, 1304,
     1301,    0,   51, 1305,  135, 1303,  119,  139, 1308, 1299,
     1295, 1298,  139,  138, 1304, 1423, 1423,  309, 1306,  177,
     1307,  202, 1296, 1308, 1423,  323, 1423, 1333,    0,    0,
      308,  216,  339,  313,  200, 1423,  217,  324, 1423, 1423,
     1315,  168,  164, 1423, 1359,  244, 1423, 1358, 1321, 1288,
     1287,  186, 1289, 1283,  183,  204, 1294, 1275, 1285, 1282,
     1280, 1277, 1288,  230, 1268, 1282, 1275, 1319,    0, 1273,

     1275, 1285, 1280, 1267,  225, 1282, 1280, 1276, 1267, 1274,
     1260, 1276,    0, 1261, 1266,    0, 1267, 1264, 1253, 1251,
     1253, 1255, 1263, 1248, 1246, 1246, 1259, 1258, 1257, 1246,
     1251, 1255, 1257, 1245, 1309, 1246, 1248, 1248, 1243, 1304,
     1245, 1245, 1243, 1240,  381,  329, 1269,  227, 1423,  273,
     1423, 1423,  343,  274, 1262, 1255, 1256,    0, 1230, 1240,
     1226, 1234, 1226, 1232, 1223, 1216, 1229, 1219, 1229, 1212,
     1215,  233, 1215, 1227, 1209, 1219, 1221, 1208, 1209, 1210,
     1253,    0,    0, 1209,    0,    0, 1200, 1209, 1197, 1204,
        0,    0, 1198, 1209, 1194,    0, 1198,    0, 1193, 1193,

     1192, 1189, 1202, 1191, 1196, 1201, 1200, 1201,    0, 1197,
     1186, 1192,    0, 1179, 1192, 1249, 1423, 1181, 1245, 1246,
     1186, 1244, 1423, 1184, 1184, 1239, 1174,  375, 1423,  263,
     1423,  310,    0, 1193, 1196,    0, 1165, 1163, 1163,  299,
     1180,  381, 1163, 1176, 1160, 1165, 1171, 1174, 1165,  295,
     1159, 1165, 1152, 1156, 1166, 1163, 1148, 1165,    0,    0,
        0, 1151, 1152, 1158, 1148,    0,    0, 1156, 1141, 1150,
     1144,    0, 1153, 1150, 1152, 1135, 1145, 1148, 1146,    0,
     1136, 1140,    0, 1143, 1200, 1199, 1423, 1198,  263, 1138,
      400, 1142, 1184, 1178, 1423, 1170, 1146,  373, 1126, 1117,

     1116, 1133, 1130,  408, 1133, 1123, 1119, 1111, 1111, 1114,
     1108, 1112, 1159, 1156, 1103, 1109, 1104, 1115, 1118, 1103,
     1152, 1097, 1095, 1095,    0,    0,    0, 1108, 1109,    0,
        0,    0,    0,    0,    0, 1111, 1104, 1104, 1096, 1158,
     1159, 1423, 1158, 1423,  377,  412,  393,  424, 1155, 1423,
     1135, 1132,  408, 1135, 1132, 1087, 1081, 1083, 1084, 1095,
     1079,  434, 1091,    0,    0, 1076, 1073,  275, 1085, 1118,
        0, 1076, 1086, 1077, 1081, 1072, 1077, 1116, 1072, 1075,
        0, 1062, 1059, 1065, 1127, 1071, 1069,    0, 1073, 1125,
      438, 1423,  316,  430,  451, 1124, 1123, 1069, 1100, 1096,

        0, 1043, 1042,    0, 1050, 1045, 1057, 1049, 1048,  453,
     1039, 1053, 1048, 1090, 1091, 1054, 1053, 1040,    0, 1048,
     1050, 1037, 1048, 1076, 1034,    0,    0,    0, 1030, 1041,
        0,    0, 1087, 1057,  428, 1041, 1093,  457, 1423,  415,
     1092, 1423, 1091, 1423, 1056, 1036, 1012,    0,    0,    0,
     1018,    0, 1018, 1031, 1031, 1015, 1010, 1025, 1012, 1055,
        0, 1025, 1005,    0, 1004, 1022,    0, 1021, 1020, 1014,
     1015, 1009, 1423, 1060, 1028,  439, 1029,  458, 1023, 1031,
        0, 1006, 1007,  990,  987,  995, 1001,  461,  991,    0,
        0,    0, 1004,    0,    0,  984, 1002, 1000,  999,  999,

      461, 1011,  462, 1008, 1006,  992,  993,  984,  977,  990,
      990,  465,  985,  988,  987,    0,  986,  973,  967,  991,
      368,  982,  469,  989,  991,  970,  966,  965,  964,  956,
      974,    0, 1016,  461,  972,    0,    0,    0, 1022,  989,
      473,  977,  472,  975,  975,  960,    0,  960,  963,  954,
        0, 1423,  465,    0,  962,  982,  476,  979,  477,  980,
      965,  948, 1423,  937,  943,  468,  954,  964,  481,  973,
      480,  962,  971,  915,  839,  842,  474,  828,  856,  486,
      855,  487,  850,  853,  837,  828, 1423,  475,  808,  719,
      488,  711,  493,    0,  706,    0,  692,  479,  694,  703,

      492,  676,  490,    0,  657,  484,  637,  654,  495,  661,
      497,  651,  488,  628,  636,  499,  599,  500, 1423,  493,
      595,  516,  540,  580,  501,  511,  576,  626,  624, 1423,
      621,  563, 1423,  545,  558,  549,  501,  551,  549, 1423,
      543,  537, 1423,  520,  515,  442,  499,  434,  329,  315,
      295,  248,  173,  196,   93, 1423, 1423,  563,  579,  595,
      606,  617,  633,  644,  658,  674,  689,  700,  716,  732,
      743,  759,  775,  791,  807,  817,  833,  849,  865,  878,
      893,  909,  925,  941,  957,  973,  989
    } ;

static const flex_int16_t yy_def[788] =
    {   0,
      757,    1,  757,  757,  757,  758,  757,  759,  757,  757,
      757,  760,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  761,  761,
      761,  761,  761,  757,  757,  757,  757,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  757,  757,  757,  757,  757,  758,  757,
      759,  757,  759,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  760,  757,  760,  757,  757,  757,  757,
      757,  757,  757,  762,  757,  763,  757,  762,   21,   22,
      757,  757,  757,  764,  757,  757,  757,  757,  757,  757,

      757,  757,  761,  761,  761,  765,  766,  761,  757,  757,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  767,  763,
      757,  757,  757,  768,  757,  757,  757,  764,  757,  757,
      761,  761,  765,  757,  765,  766,  757,  766,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,

      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  769,  757,  757,  757,  757,  770,
      757,  757,  757,  757,  757,  771,  767,  757,  757,  757,
      757,  757,  757,  757,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,

      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  769,  757,  757,  757,  772,
      757,  770,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  757,  773,  772,  757,  774,  757,  757,
      757,  757,  757,  757,  757,  761,  761,  761,  761,  761,

      761,  761,  761,  757,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  757,
      773,  757,  774,  757,  757,  775,  757,  757,  757,  757,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      757,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  776,  757,  775,
      775,  757,  775,  757,  777,  778,  779,  761,  761,  761,

      761,  761,  761,  761,  761,  761,  761,  761,  757,  757,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  757,
      761,  761,  780,  757,  775,  757,  777,  777,  757,  777,
      778,  757,  779,  757,  761,  761,  761,  761,  761,  761,
      761,  761,  761,  757,  757,  757,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  757,  757,  780,  757,  775,  757,  777,  761,  761,
      761,  761,  761,  757,  757,  757,  761,  761,  761,  761,
      761,  761,  761,  761,  761,  761,  761,  761,  757,  757,

      775,  757,  777,  761,  761,  761,  761,  757,  757,  757,
      761,  757,  781,  761,  761,  761,  761,  761,  757,  757,
      775,  757,  777,  761,  761,  761,  761,  757,  757,  757,
      761,  781,  781,  781,  761,  761,  761,  761,  757,  757,
      775,  757,  777,  761,  761,  761,  761,  757,  757,  757,
      761,  757,  781,  761,  757,  757,  775,  757,  777,  761,
      761,  761,  757,  757,  757,  781,  757,  757,  775,  757,
      777,  761,  761,  761,  757,  757,  781,  757,  757,  775,
      757,  777,  761,  761,  761,  757,  757,  781,  757,  757,
      775,  757,  777,  761,  761,  761,  757,  781,  757,  757,

      775,  757,  777,  761,  757,  781,  757,  757,  775,  757,
      777,  757,  781,  757,  757,  775,  757,  777,  757,  781,
      757,  782,  783,  757,  777,  781,  757,  782,  782,  757,
      783,  783,  757,  784,  785,  786,  757,  784,  784,  757,
      785,  785,  757,  786,  786,  757,  786,  757,  757,  757,
      757,  757,  757,  787,  787,  757,    0,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757
    } ;

static const flex_int16_t yy_nxt[1509] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   22,   23,   24,
       25,   26,   27,   28,   29,   29,   29,   29,   29,   30,
       31,   29,   29,   32,   29,   29,   29,   29,   33,   29,
       29,   34,   35,   36,   37,   38,   39,   40,   41,   42,
       43,   44,   45,   29,   46,   29,   29,   47,   29,   29,
       29,   29,   48,   49,   50,   51,   52,   53,   29,   29,
       29,   54,   55,   56,   57,   58,   62,   58,   58,   64,
       70,   71,   72,   75,   78,  756,   83,   80,   84,   84,

       84,   84,   84,   84,   84,   84,   84,   96,  101,  102,
       85,   79,   81,   82,   73,   86,  106,  116,  215,  117,
      107,  118,  146,  119,  120,  216,  123,   97,   87,   98,
       99,  121,   63,  111,   75,   76,  124,  112,  122,  125,
      128,  126,  113,  177,   65,   66,  114,  132,   62,   67,
      127,  129,   68,  115,  130,  133,   69,   88,  174,   89,
       89,   89,   89,   89,   89,   89,   90,   90,  136,  137,
      174,  140,   58,  147,   58,   58,   76,  167,   91,  138,
      141,  222,  139,   92,  150,  178,  151,  142,  182,   93,
       94,  156,  157,  183,   63,  224,  157,  218,  756,  223,

       91,  167,  232,  230,  175,  233,  240,   92,  219,  220,
      256,  225,  231,  156,  157,   93,  175,  257,   94,   88,
      157,   90,   90,   90,   90,   90,   90,   90,   90,   90,
      148,  148,  148,  148,  148,  148,  148,  148,  148,  158,
       91,  237,  158,  156,  157,   92,  161,  754,  157,  166,
      238,   93,  162,  757,  177,  261,  265,  266,  262,  250,
      252,  241,   91,  267,  445,  156,  157,  446,  159,   92,
      161,  242,  157,  165,  268,  166,  249,   93,  162,  166,
      163,  757,  163,  250,  252,  164,  164,  164,  164,  164,
      164,  164,  164,  164,  276,  514,  178,  165,  287,  288,

      349,  515,  249,  753,  277,  166,  185,  350,  186,  187,
      188,  189,  331,  235,  190,  413,  329,  332,  492,  191,
      414,  192,  193,  194,  195,  196,  197,  198,  148,  148,
      148,  148,  148,  148,  148,  148,  148,  245,  331,  245,
      329,  332,  246,  246,  246,  246,  246,  246,  246,  246,
      246,  248,  251,  395,  401,  402,  251,  249,  164,  164,
      164,  164,  164,  164,  164,  164,  164,  253,  157,  752,
      492,  535,  157,  254,  251,  248,  393,  395,  445,  393,
      251,  445,  404,  249,  404,  404,  330,  751,  394,  750,
      157,  253,  331,  453,  494,  454,  157,  495,  455,  254,

      246,  246,  246,  246,  246,  246,  246,  246,  246,  404,
      330,  404,  404,  491,  492,  641,  491,  539,  331,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  496,  500,
      492,  494,  489,  501,  494,  510,  405,  510,  510,  491,
      492,  492,  491,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  538,  539,  510,  538,  510,  510,  538,  539,
      539,  538,  612,  492,  539,  612,  612,  493,  576,  612,
      578,  539,  613,  652,  539,  492,  632,  652,  492,  539,
      652,  601,  539,  492,  461,  536,  652,  652,  492,  539,
      492,  652,  539,  493,  492,  539,  652,  492,  603,  539,

      652,  492,  539,  539,  623,  652,  540,  749,  555,  657,
      669,  747,  540,  671,  682,  748,  621,  729,  730,  659,
      729,  653,  736,  652,  643,  680,  701,  747,  711,  556,
      691,  693,  745,  698,  688,  706,  666,  703,  709,  743,
      677,  732,  733,  718,  732,  743,  739,  740,  720,  739,
      716,  740,  726,  740,  723,  725,  735,  746,  713,  742,
      743,  745,  742,   59,   59,  733,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   74,   74,   74,   74,   74,

       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       74,  103,  103,  103,  103,  103,  103,  103,  103,  103,
      103,  103,   84,  733,   84,   84,  730,   84,  730,   84,
       84,  737,   84,  160,  160,  734,  160,  160,  160,  160,
      160,  160,  160,  160,  160,  160,  160,  160,  160,  168,
      168,  168,  168,  727,  724,  168,  168,  168,  173,  173,
      173,  173,  173,  173,  173,  173,  173,  173,  173,  173,
      173,  173,  173,  173,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      247,  722,  721,  247,  247,  247,  247,  247,  247,  247,

      247,  247,  247,  247,  247,  164,  719,  717,  164,  715,
      164,  714,  712,  164,  710,  164,  316,  316,  316,  316,
      316,  316,  316,  316,  316,  316,  316,  316,  316,  316,
      316,  316,  322,  322,  322,  322,  322,  322,  322,  322,
      322,  322,  322,  322,  322,  322,  322,  322,  246,  708,
      707,  246,  705,  246,  704,  702,  246,  700,  246,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  441,  441,  441,  441,  441,
      441,  441,  441,  441,  441,  441,  441,  441,  441,  441,
      441,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  443,  443,  443,  443,  443,  443,  490,  490,  490,
      490,  490,  490,  490,  490,  490,  490,  490,  490,  490,
      490,  490,  490,  533,  533,  533,  533,  533,  533,  533,
      533,  533,  533,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  543,  543,  543,  543,  543,
      543,  543,  543,  543,  543,  543,  543,  543,  543,  543,
      543,  574,  699,  574,  574,  574,  574,  574,  574,  574,
      574,  574,  574,  574,  633,  697,  696,  695,  694,  692,

      690,  689,  687,  686,  633,  633,  633,  633,  633,  728,
      728,  728,  728,  728,  728,  728,  728,  728,  728,  728,
      728,  728,  728,  728,  728,  731,  731,  731,  731,  731,
      731,  731,  731,  731,  731,  731,  731,  731,  731,  731,
      731,  738,  738,  738,  738,  738,  738,  738,  738,  738,
      738,  738,  738,  738,  738,  738,  738,  741,  741,  741,
      741,  741,  741,  741,  741,  741,  741,  741,  741,  741,
      741,  741,  741,  744,  744,  685,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  755,
      755,  755,  755,  755,  755,  755,  755,  755,  755,  755,

      755,  755,  755,  755,  755,  684,  683,  681,  679,  678,
      676,  675,  674,  673,  672,  670,  668,  667,  665,  664,
      663,  662,  661,  660,  658,  656,  655,  654,  652,  651,
      650,  649,  648,  647,  646,  645,  644,  642,  640,  639,
      638,  637,  636,  635,  634,  631,  630,  629,  628,  627,
      626,  625,  624,  622,  620,  619,  618,  617,  616,  615,
      614,  611,  610,  609,  608,  607,  606,  605,  604,  602,
      600,  573,  599,  598,  597,  596,  595,  594,  593,  592,
      591,  590,  589,  588,  587,  586,  585,  584,  583,  582,
      581,  580,  579,  544,  542,  539,  577,  575,  573,  572,

      571,  570,  569,  568,  567,  566,  565,  564,  563,  562,
      561,  560,  559,  558,  557,  554,  553,  552,  551,  550,
      549,  548,  547,  546,  545,  544,  542,  492,  534,  532,
      531,  530,  529,  528,  527,  526,  525,  524,  523,  522,
      521,  520,  519,  518,  517,  516,  513,  512,  511,  509,
      508,  507,  506,  505,  504,  503,  502,  499,  498,  497,
      444,  442,  488,  487,  486,  485,  484,  483,  482,  481,
      480,  479,  478,  477,  476,  475,  474,  473,  472,  471,
      470,  469,  468,  467,  466,  465,  464,  463,  462,  460,
      459,  458,  457,  456,  452,  451,  450,  394,  449,  447,

      444,  387,  442,  440,  439,  438,  437,  436,  435,  434,
      433,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  412,
      411,  410,  409,  408,  407,  406,  403,  400,  399,  398,
      397,  396,  392,  391,  390,  389,  323,  388,  387,  385,
      384,  317,  383,  382,  381,  380,  379,  378,  377,  376,
      375,  374,  373,  372,  371,  370,  369,  368,  367,  366,
      365,  364,  363,  362,  361,  360,  359,  358,  357,  356,
      355,  354,  353,  352,  351,  348,  347,  346,  345,  344,
      343,  342,  341,  340,  339,  338,  337,  336,  335,  334,

      333,  328,  327,  326,  325,  324,  323,  321,  320,  319,
      318,  317,  315,  314,  313,  312,  311,  310,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  300,  299,  298,
      297,  296,  295,  294,  293,  292,  291,  290,  289,  286,
      285,  284,  283,  282,  281,  280,  279,  278,  275,  274,
      273,  272,  271,  270,  269,  264,  263,  260,  259,  258,
      757,  757,  255,  159,  244,  243,  239,  236,  234,  229,
      228,  227,  226,  221,  217,  214,  213,  212,  211,  210,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  184,  181,  180,  179,  172,  171,  170,  169,  155,

      757,  154,  153,  152,  149,  757,  145,  144,  143,  135,
      134,  131,  110,  109,  108,  105,  104,  100,   95,   77,
       60,  757,    3,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,

      757,  757,  757,  757,  757,  757,  757,  757
    } ;

static const flex_int16_t yy_chk[1509] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    5,    8,    5,    5,    9,
       10,   10,   11,   12,   16,  755,   19,   18,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   25,   27,   27,
       20,   16,   18,   18,   11,   20,   32,   39,  133,   39,
       32,   40,   55,   40,   41,  133,   42,   25,   20,   25,
       25,   41,    8,   38,   74,   12,   42,   38,   41,   43,
       44,   43,   38,  107,    9,    9,   38,   46,   61,    9,
       43,   44,    9,   38,   44,   46,    9,   21,  106,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   49,   49,
      173,   50,   58,   55,   58,   58,   74,   93,   21,   49,
       50,  137,   49,   21,   66,  107,   66,   50,  113,   21,
       21,   84,   84,  113,   61,  138,   84,  135,  754,  137,

       21,   93,  144,  143,  106,  144,  152,   21,  135,  135,
      172,  138,  143,   84,   84,   21,  173,  172,   21,   22,
       84,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   85,
       22,  150,   85,   88,   88,   22,   89,  753,   88,  165,
      150,   22,   89,   89,  176,  182,  185,  185,  182,  162,
      167,  152,   22,  186,  389,   88,   88,  389,   85,   22,
       89,  152,   88,   92,  186,  165,  248,   22,   89,   92,
       91,   89,   91,  162,  167,   91,   91,   91,   91,   91,
       91,   91,   91,   91,  194,  468,  176,   92,  205,  205,

      272,  468,  248,  752,  194,   92,  115,  272,  115,  115,
      115,  115,  330,  148,  115,  350,  250,  254,  493,  115,
      350,  115,  115,  115,  115,  115,  115,  115,  148,  148,
      148,  148,  148,  148,  148,  148,  148,  156,  330,  156,
      250,  254,  156,  156,  156,  156,  156,  156,  156,  156,
      156,  161,  164,  332,  340,  340,  164,  161,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  168,  246,  751,
      621,  493,  246,  168,  164,  161,  328,  332,  445,  328,
      164,  445,  342,  161,  342,  342,  253,  750,  328,  749,
      246,  168,  253,  398,  447,  398,  246,  447,  398,  168,

      245,  245,  245,  245,  245,  245,  245,  245,  245,  404,
      253,  404,  404,  446,  446,  621,  446,  540,  253,  391,
      391,  391,  391,  391,  391,  391,  391,  391,  448,  453,
      535,  494,  445,  453,  494,  462,  342,  462,  462,  491,
      491,  576,  491,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  495,  495,  510,  495,  510,  510,  538,  538,
      578,  538,  588,  601,  603,  588,  612,  446,  535,  612,
      540,  623,  588,  634,  643,  641,  612,  653,  657,  659,
      666,  576,  671,  669,  404,  494,  677,  688,  680,  682,
      691,  698,  703,  491,  701,  693,  706,  709,  578,  711,

      713,  716,  718,  725,  603,  720,  495,  748,  510,  641,
      657,  747,  538,  659,  671,  746,  601,  722,  722,  643,
      722,  634,  726,  726,  623,  669,  691,  745,  703,  510,
      680,  682,  744,  688,  677,  698,  653,  693,  701,  742,
      666,  723,  723,  711,  723,  741,  734,  734,  713,  734,
      709,  739,  720,  738,  716,  718,  725,  737,  706,  735,
      735,  736,  735,  758,  758,  732,  758,  758,  758,  758,
      758,  758,  758,  758,  758,  758,  758,  758,  758,  759,
      759,  759,  759,  759,  759,  759,  759,  759,  759,  759,
      759,  759,  759,  759,  759,  760,  760,  760,  760,  760,

      760,  760,  760,  760,  760,  760,  760,  760,  760,  760,
      760,  761,  761,  761,  761,  761,  761,  761,  761,  761,
      761,  761,  762,  731,  762,  762,  729,  762,  728,  762,
      762,  727,  762,  763,  763,  724,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  764,
      764,  764,  764,  721,  717,  764,  764,  764,  765,  765,
      765,  765,  765,  765,  765,  765,  765,  765,  765,  765,
      765,  765,  765,  765,  766,  766,  766,  766,  766,  766,
      766,  766,  766,  766,  766,  766,  766,  766,  766,  766,
      767,  715,  714,  767,  767,  767,  767,  767,  767,  767,

      767,  767,  767,  767,  767,  768,  712,  710,  768,  708,
      768,  707,  705,  768,  702,  768,  769,  769,  769,  769,
      769,  769,  769,  769,  769,  769,  769,  769,  769,  769,
      769,  769,  770,  770,  770,  770,  770,  770,  770,  770,
      770,  770,  770,  770,  770,  770,  770,  770,  771,  700,
      699,  771,  697,  771,  695,  692,  771,  690,  771,  772,
      772,  772,  772,  772,  772,  772,  772,  772,  772,  772,
      772,  772,  772,  772,  772,  773,  773,  773,  773,  773,
      773,  773,  773,  773,  773,  773,  773,  773,  773,  773,
      773,  774,  774,  774,  774,  774,  774,  774,  774,  774,

      774,  774,  774,  774,  774,  774,  774,  775,  775,  775,
      775,  775,  775,  775,  775,  775,  775,  775,  775,  775,
      775,  775,  775,  776,  776,  776,  776,  776,  776,  776,
      776,  776,  776,  777,  777,  777,  777,  777,  777,  777,
      777,  777,  777,  777,  777,  777,  777,  777,  777,  778,
      778,  778,  778,  778,  778,  778,  778,  778,  778,  778,
      778,  778,  778,  778,  778,  779,  779,  779,  779,  779,
      779,  779,  779,  779,  779,  779,  779,  779,  779,  779,
      779,  780,  689,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  781,  686,  685,  684,  683,  681,

      679,  678,  676,  675,  781,  781,  781,  781,  781,  782,
      782,  782,  782,  782,  782,  782,  782,  782,  782,  782,
      782,  782,  782,  782,  782,  783,  783,  783,  783,  783,
      783,  783,  783,  783,  783,  783,  783,  783,  783,  783,
      783,  784,  784,  784,  784,  784,  784,  784,  784,  784,
      784,  784,  784,  784,  784,  784,  784,  785,  785,  785,
      785,  785,  785,  785,  785,  785,  785,  785,  785,  785,
      785,  785,  785,  786,  786,  674,  786,  786,  786,  786,
      786,  786,  786,  786,  786,  786,  786,  786,  786,  787,
      787,  787,  787,  787,  787,  787,  787,  787,  787,  787,

      787,  787,  787,  787,  787,  673,  672,  670,  668,  667,
      665,  664,  662,  661,  660,  658,  656,  655,  650,  649,
      648,  646,  645,  644,  642,  640,  639,  635,  633,  631,
      630,  629,  628,  627,  626,  625,  624,  622,  620,  619,
      618,  617,  615,  614,  613,  611,  610,  609,  608,  607,
      606,  605,  604,  602,  600,  599,  598,  597,  596,  593,
      589,  587,  586,  585,  584,  583,  582,  580,  579,  577,
      575,  574,  572,  571,  570,  569,  568,  566,  565,  563,
      562,  560,  559,  558,  557,  556,  555,  554,  553,  551,
      547,  546,  545,  543,  541,  537,  536,  534,  533,  530,

      529,  525,  524,  523,  522,  521,  520,  518,  517,  516,
      515,  514,  513,  512,  511,  509,  508,  507,  506,  505,
      503,  502,  500,  499,  498,  497,  496,  490,  489,  487,
      486,  485,  484,  483,  482,  480,  479,  478,  477,  476,
      475,  474,  473,  472,  470,  469,  467,  466,  463,  461,
      460,  459,  458,  457,  456,  455,  454,  452,  451,  449,
      443,  441,  440,  439,  438,  437,  436,  429,  428,  424,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  414,
      413,  412,  411,  410,  409,  408,  407,  406,  405,  403,
      402,  401,  400,  399,  397,  396,  394,  393,  392,  390,

      388,  386,  385,  384,  382,  381,  379,  378,  377,  376,
      375,  374,  373,  371,  370,  369,  368,  365,  364,  363,
      362,  358,  357,  356,  355,  354,  353,  352,  351,  349,
      348,  347,  346,  345,  344,  343,  341,  339,  338,  337,
      335,  334,  327,  326,  325,  324,  322,  321,  320,  319,
      318,  316,  315,  314,  312,  311,  310,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  299,  297,  295,  294,
      293,  290,  289,  288,  287,  284,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  271,  270,  269,  268,  267,
      266,  265,  264,  263,  262,  261,  260,  259,  257,  256,

      255,  247,  244,  243,  242,  241,  240,  239,  238,  237,
      236,  235,  234,  233,  232,  231,  230,  229,  228,  227,
      226,  225,  224,  223,  222,  221,  220,  219,  218,  217,
      215,  214,  212,  211,  210,  209,  208,  207,  206,  204,
      203,  202,  201,  200,  198,  197,  196,  195,  193,  192,
      191,  190,  189,  188,  187,  184,  183,  181,  180,  179,
      178,  175,  171,  158,  154,  153,  151,  149,  145,  142,
      141,  140,  139,  136,  134,  131,  130,  129,  128,  127,
      126,  125,  124,  123,  122,  121,  120,  119,  118,  117,
      116,  114,  112,  111,  108,  105,  104,  102,   98,   83,

       76,   69,   68,   67,   65,   63,   53,   52,   51,   48,
       47,   45,   37,   35,   33,   31,   30,   26,   23,   15,
        7,    3,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,
      757,  757,  757,  757,  757,  757,  757,  757,  757,  757,

      757,  757,  757,  757,  757,  757,  757,  757
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#ifndef _WIN32
#include <limits.h>
#else
#include <io.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner, gboolean has_line);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);

#if (YY_FLEX_MAJOR_VERSION > 2) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION > 6)) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION == 6) && (YY_FLEX_SUBMINOR_VERSION >= 1))
#define IS_EOF 0
#else
#define IS_EOF EOF
#endif

#line 1233 "giscanner/scannerlexer.c"
#line 1234 "giscanner/scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 80 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"


#line 1458 "giscanner/scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 758 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1423 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];

find_rule: /* we branch to this label when backing up */

		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 82 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 88 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 90 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 92 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 93 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 94 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 96 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 97 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 98 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 99 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 100 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 101 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 102 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 103 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 104 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 105 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 106 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 108 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, FALSE); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 109 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, TRUE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 110 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 111 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 112 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 113 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 114 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 115 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 116 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 117 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 118 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 119 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 120 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 121 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 122 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 123 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 124 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 125 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 126 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 127 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 128 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 129 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 130 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 131 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 132 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 133 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 134 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 135 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 136 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 137 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 138 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 139 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 140 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 141 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 142 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 143 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 144 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 145 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 146 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 147 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 148 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 149 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 150 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 151 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 152 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 153 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 154 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 155 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 156 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 157 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 158 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 159 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 160 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 162 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 163 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 164 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 165 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 166 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 167 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 168 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 169 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 170 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 171 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 172 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 173 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 174 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 175 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 176 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 177 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 178 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 179 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 180 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 181 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 182 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 183 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (parse_ignored_macro()) return VOID; else REJECT; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 184 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (parse_ignored_macro()) return VOID; else REJECT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 185 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 186 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 187 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 188 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 98:
/* rule 98 can match eol */
YY_RULE_SETUP
#line 189 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ ++lineno; /* Ignore */ }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 190 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 191 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 192 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 193 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 194 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 196 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 197 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 199 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 200 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 201 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 202 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 204 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 206 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 207 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 208 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 209 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 210 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 211 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 212 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 213 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 214 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 215 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 216 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 217 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 218 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 219 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 220 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 221 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 222 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 223 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 224 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 225 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 226 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 227 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 228 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 229 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 230 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 231 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 232 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 233 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 234 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 235 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 236 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 237 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 238 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 239 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 240 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 241 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 242 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 243 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 244 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 245 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 246 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 247 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 248 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 249 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 250 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 251 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 252 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 253 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 254 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 255 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 256 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 258 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 260 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 261 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 262 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 264 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 265 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 168:
/* rule 168 can match eol */
YY_RULE_SETUP
#line 267 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 169:
/* rule 169 can match eol */
YY_RULE_SETUP
#line 268 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 170:
/* rule 170 can match eol */
YY_RULE_SETUP
#line 270 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 171:
/* rule 171 can match eol */
YY_RULE_SETUP
#line 271 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 273 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 275 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2408 "giscanner/scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 758 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 758 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 757);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 275 "../gobject-introspection-1.78.1/giscanner/scannerlexer.l"


static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != IS_EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

#ifdef _WIN32
/* We don't want to include <windows.h> as it clashes horribly
 * with token names from scannerparser.h. So just declare
 * GetFullPathNameA() here unless we already defined it, like
 * in giscanner.c.
 */
extern unsigned long __stdcall GetFullPathNameA(const char*, int, char*, char**);
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != IS_EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != IS_EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != IS_EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    gchar *error = g_strdup_printf ("%s:%d: unexpected character `%c'", filename, lineno, yytext[0]);
    g_ptr_array_add (scanner->errors, error);
    g_free (filename);
  }
}

